@@ -1,21 +1,19 @@
-#' Sample from a piecewise-constant exponential distribution.
+#' Draws Waiting Times from a Piecewise-Exponential Distribution.
 #' 
-#' Takes n random draws from a piecewise-constant exponential distribution.
+#' The function produces n realizations of a piecewise-exponentially distributed random waiting time.
 #' 
 #' 
-#' @param n Number of random draws required
-#' @param breakpoints Breakpoints in piecewise-constant exponential
-#' distribution
+#' @param n Number of random draws
+#' @param breakpoints Breakpoints in piecewise-exponential distribution
 #' @param rates Piecewise-constant rates
-#' @return Vector of waiting times, drawn from piecewise-exponential survival
+#' @return Vector of waiting times, drawn randomly from a piecewise-exponential survival
 #' function.
-#' @author Frans Willekens
 #' @examples
 #' 
 #' 
 #' breakpoints <- c(0, 10, 20, 30, 60)
 #' rates <- c(0.01,0.02,0.04,0.15)
-#' pw_sample <- r.pw_exp (n=10, breakpoints, rates=rates)
+#' pw_sample <- VirtualPop::r.pw_exp (n=10, breakpoints, rates=rates)
 #' 
 #' 
 #' @export r.pw_exp
@@ -23,22 +21,17 @@ r.pw_exp <-
 function (n, breakpoints, rates) 
 {
     success = TRUE
-    if (!exists("pw_root")) 
-        warning ("r.pw_exp: pw_root does not exist")
-    if (!exists("H_pw")) 
-        warning ("r.pw_exp: H_pw does not exist")
     i <- 1
     u <- runif(n)
     interval = c(breakpoints[1], breakpoints[length(breakpoints)])
     x_Dg <- vector(mode = "numeric", length = n)
     while (success == TRUE & i <= n) {
-        xx <- tryCatch(uniroot(f = pw_root, interval = interval, 
+        xx <- base::tryCatch(uniroot(f = pw_root, interval = interval, 
             breakpoints, rates, uu = u[i])$root, error = function(e) z = 5000)
         if (xx == 5000) {
             success <- TRUE
             u[i] <- runif(1)
-        }
-        else {
+        } else {
             x_Dg[i] <- xx
             i = i + 1
         }
